@@ -18,8 +18,10 @@ PhyloTree::PhyloTree(){
 		numSeqs = 0;
 		tree.push_back(TaxNode("Root"));
 		tree[0].heirarchyID = "0";
+        tree[0].level = 0;
 		maxLevel = 0;
 		calcTotals = true;
+        
 		addSeqToTree("unknown", "unknown;");
 	}
 	catch(exception& e) {
@@ -46,7 +48,8 @@ PhyloTree::PhyloTree(ifstream& in, string filename){
         in >> maxLevel; m->gobble(in);
         
         for (int i = 0; i < tree.size(); i++) {
-            in >> tree[i].name >> tree[i].level >> tree[i].parent; m->gobble(in);
+            tree[i].name = m->getline(in); m->gobble(in);
+            in >> tree[i].level >> tree[i].parent; m->gobble(in);
         }
         
         //read genus nodes
@@ -77,6 +80,7 @@ PhyloTree::PhyloTree(string tfile){
 		numSeqs = 0;
 		tree.push_back(TaxNode("Root"));
 		tree[0].heirarchyID = "0";
+        tree[0].level = 0;
 		maxLevel = 0;
 		calcTotals = true;
 		string name, tax;
@@ -89,16 +93,15 @@ PhyloTree::PhyloTree(string tfile){
             temp.erase(itTemp++);
         }
         
-		assignHeirarchyIDs(0);
-        
         string unknownTax = "unknown;";
         //added last taxon until you get desired level
 		for (int i = 1; i < maxLevel; i++) {
 			unknownTax += "unknown_unclassfied;";
 		}
-        
         addSeqToTree("unknown", unknownTax);
         
+        assignHeirarchyIDs(0);
+        
 		//create file for summary if needed
 		setUp(tfile);
 	}
@@ -190,8 +193,7 @@ int PhyloTree::addSeqToTree(string seqName, string seqTaxonomy){
 		
 		tree[0].accessions.push_back(seqName);
 		m->removeConfidences(seqTaxonomy);
-		
-		string taxon;// = getNextTaxon(seqTaxonomy);
+        string taxon;// = getNextTaxon(seqTaxonomy);
 	
 		while(seqTaxonomy != ""){
 			
@@ -216,11 +218,13 @@ int PhyloTree::addSeqToTree(string seqName, string seqTaxonomy){
 			}
 			else{											//otherwise, create it
 				tree.push_back(TaxNode(taxon));
-				numNodes++;
-				tree[currentNode].children[taxon] = numNodes-1;
-				tree[numNodes-1].parent = currentNode;
 				
-				currentNode = tree[currentNode].children[taxon];
+				tree[currentNode].children[taxon] = numNodes;
+                tree[numNodes].level = level;
+				tree[numNodes].parent = currentNode;
+                currentNode = numNodes;
+                numNodes++;
+				
 				tree[currentNode].accessions.push_back(seqName);
 				name2Taxonomy[seqName] = currentNode;
 			}
@@ -232,7 +236,7 @@ int PhyloTree::addSeqToTree(string seqName, string seqTaxonomy){
         //save maxLevel for binning the unclassified seqs
         if (level > maxLevel) { maxLevel = level; }
         
-		return 0;
+		return level;
 	}
 	catch(exception& e) {
 		m->errorOut(e, "PhyloTree", "addSeqToTree");
@@ -295,7 +299,7 @@ void PhyloTree::assignHeirarchyIDs(int index){
                 
 			tree[it->second].heirarchyID = tree[index].heirarchyID + '.' + toString(counter);
 			counter++;
-			tree[it->second].level = tree[index].level + 1;
+			//tree[it->second].level = tree[index].level + 1;
 						
 			//save maxLevel for binning the unclassified seqs
 			if (tree[it->second].level > maxLevel) { maxLevel = tree[it->second].level; } 
@@ -373,12 +377,12 @@ void PhyloTree::binUnclassified(string file){
 				}
 				else{											//otherwise, create it
 					copy.push_back(TaxNode(taxon));
-					copyNodes++;
-					copy[currentNode].children[taxon] = copyNodes-1;
-					copy[copyNodes-1].parent = currentNode;
-					copy[copyNodes-1].level = copy[currentNode].level + 1;
-									
-					currentNode = copy[currentNode].children[taxon];
+					
+					copy[currentNode].children[taxon] = copyNodes;
+					copy[copyNodes].parent = currentNode;
+					copy[copyNodes].level = copy[currentNode].level + 1;
+                    currentNode = copyNodes;
+                    copyNodes++;
 				}
 			}
 		}
@@ -454,11 +458,12 @@ void PhyloTree::print(ofstream& out, vector<TaxNode>& copy){
 				
 		for (int i = 0; i < copy.size(); i++) {
 				
-			out << copy[i].level << '\t'<< copy[i].name << '\t' << copy[i].children.size();
+			out << copy[i].level << '\t' << copy[i].children.size() << endl;
+            out << copy[i].name << endl;
 			
 			map<string,int>::iterator it;
 			for(it=copy[i].children.begin();it!=copy[i].children.end();it++){
-				out << '\t' << it->first << '\t' << it->second;
+				out << it->second << '\t' << it->first << endl;
 			}
 			out << endl;
 		}
@@ -485,7 +490,8 @@ void PhyloTree::printTreeNodes(string treefilename) {
         outTree << maxLevel << endl;
         
         for (int i = 0; i < tree.size(); i++) {
-            outTree << tree[i].name << '\t' << tree[i].level << '\t' << tree[i].parent << endl;
+            outTree << tree[i].name << endl;
+            outTree << tree[i].level << '\t' << tree[i].parent << endl;
         }
         
         //print genus nodes
