@@ -398,7 +398,7 @@ int CommandFactory::checkForRedirects(string optionString) {
             }
 
             if (seed)  {
-                srand(random);
+                m->setRandomSeed(random);
                 m->mothurOut("Setting random seed to " + toString(random) + ".\n\n");
             }
         }
@@ -556,7 +556,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString){
         else if(commandName == "make.contigs")          {	command = new MakeContigsCommand(optionString);             }
         else if(commandName == "sff.multiple")          {	command = new SffMultipleCommand(optionString);             }
         else if(commandName == "classify.svm")          {   command = new ClassifySvmSharedCommand(optionString);       }
-        else if(commandName == "classify.rf")           {	command = new ClassifyRFSharedCommand(optionString);          }
+        //else if(commandName == "classify.rf")           {	command = new ClassifyRFSharedCommand(optionString);          }
         else if(commandName == "filter.shared")         {	command = new FilterSharedCommand(optionString);            }
         else if(commandName == "primer.design")         {	command = new PrimerDesignCommand(optionString);            }
         else if(commandName == "get.dists")             {	command = new GetDistsCommand(optionString);                }
@@ -729,7 +729,7 @@ Command* CommandFactory::getCommand(string commandName, string optionString, str
         else if(commandName == "get.coremicrobiome")    {	pipecommand = new GetCoreMicroBiomeCommand(optionString);       }
         else if(commandName == "make.contigs")          {	pipecommand = new MakeContigsCommand(optionString);             }
         else if(commandName == "sff.multiple")          {	pipecommand = new SffMultipleCommand(optionString);             }
-        else if(commandName == "classify.rf")           {	pipecommand = new ClassifyRFSharedCommand(optionString);        }
+        //else if(commandName == "classify.rf")           {	pipecommand = new ClassifyRFSharedCommand(optionString);        }
         else if(commandName == "filter.shared")         {	pipecommand = new FilterSharedCommand(optionString);            }
         else if(commandName == "primer.design")         {	pipecommand = new PrimerDesignCommand(optionString);            }
         else if(commandName == "get.dists")             {	pipecommand = new GetDistsCommand(optionString);                }
@@ -889,7 +889,7 @@ Command* CommandFactory::getCommand(string commandName){
         else if(commandName == "get.coremicrobiome")    {	shellcommand = new GetCoreMicroBiomeCommand();      }
         else if(commandName == "make.contigs")          {	shellcommand = new MakeContigsCommand();            }
         else if(commandName == "sff.multiple")          {	shellcommand = new SffMultipleCommand();            }
-        else if(commandName == "classify.rf")           {	shellcommand = new ClassifyRFSharedCommand();       }
+        //else if(commandName == "classify.rf")           {	shellcommand = new ClassifyRFSharedCommand();       }
         else if(commandName == "filter.shared")         {	shellcommand = new FilterSharedCommand();           }
         else if(commandName == "primer.design")         {	shellcommand = new PrimerDesignCommand();           }
         else if(commandName == "get.dists")             {	shellcommand = new GetDistsCommand();               }
