@@ -26,7 +26,6 @@ vector<string> ChimeraPintailCommand::setParameters(){
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
-		CommandParameter psave("save", "Boolean", "", "F", "", "", "","",false,false); parameters.push_back(psave);
 
 		vector<string> myArray;
 		for (int i = 0; i < parameters.size(); i++) {	myArray.push_back(parameters[i].name);		}
@@ -50,10 +49,6 @@ string ChimeraPintailCommand::getHelpString(){
 		helpString += "The filter parameter allows you to specify if you would like to apply a vertical and 50% soft filter. \n";
 		helpString += "The mask parameter allows you to specify a file containing one sequence you wish to use as a mask for the your sequences, by default no mask is applied.  You can apply an ecoli mask by typing, mask=default. \n";
 		helpString += "The processors parameter allows you to specify how many processors you would like to use.  The default is 1. \n";
-#ifdef USE_MPI
-		helpString += "When using MPI, the processors parameter is set to the number of MPI processes running. \n";
-#endif
-		helpString += "If the save parameter is set to true the reference sequences will be saved in memory, to clear them later you can use the clear.memory command. Default=f.";
 		helpString += "The window parameter allows you to specify the window size for searching for chimeras, default=300. \n";
 		helpString += "The increment parameter allows you to specify how far you move each window while finding chimeric sequences, default=25.\n";
 		helpString += "The conservation parameter allows you to enter a frequency file containing the highest bases frequency at each place in the alignment.\n";
@@ -104,7 +99,6 @@ ChimeraPintailCommand::ChimeraPintailCommand(){
 ChimeraPintailCommand::ChimeraPintailCommand(string option)  {
 	try {
 		abort = false; calledHelp = false;   
-		rdb = ReferenceDB::getInstance();
 		
 		//allow user to run help
 		if(option == "help") { help(); abort = true; calledHelp = true; }
@@ -252,26 +246,11 @@ ChimeraPintailCommand::ChimeraPintailCommand(string option)  {
 			temp = validParameter.validFile(parameters, "increment", false);		if (temp == "not found") { temp = "25"; }
 			m->mothurConvert(temp, increment);
 			
-			temp = validParameter.validFile(parameters, "save", false);			if (temp == "not found"){	temp = "f";				}
-			save = m->isTrue(temp); 
-			rdb->save = save; 
-			if (save) { //clear out old references
-				rdb->clearMemory();	
-			}
 			
 			//this has to go after save so that if the user sets save=t and provides no reference we abort
 			templatefile = validParameter.validFile(parameters, "reference", true);
-			if (templatefile == "not found") { 
-				//check for saved reference sequences
-				if (rdb->referenceSeqs.size() != 0) {
-					templatefile = "saved";
-				}else {
-					m->mothurOut("[ERROR]: You don't have any saved reference sequences and the reference parameter is a required."); 
-					m->mothurOutEndLine();
-					abort = true; 
-				}
-			}else if (templatefile == "not open") { abort = true; }	
-			else {	if (save) {	rdb->setSavedReference(templatefile);	}	}
+			if (templatefile == "not found") { m->mothurOut("[ERROR]: The reference parameter is a required, aborting.\n"); abort = true;
+			}else if (templatefile == "not open") { abort = true; }
 			
 			
 			maskfile = validParameter.validFile(parameters, "mask", false);
@@ -371,7 +350,6 @@ int ChimeraPintailCommand::execute(){
 			
 			//check for quantile to save the time
 			string baseName = templatefile;
-			if (templatefile == "saved") { baseName = rdb->getSavedReference(); }
 			
 			string tempQuan = "";
 			if ((!filter) && (maskfile == "")) {
@@ -431,80 +409,7 @@ int ChimeraPintailCommand::execute(){
 			}
 			templateSeqsLength = chimera->getLength();
 		
-		#ifdef USE_MPI
-			int pid, numSeqsPerProcessor; 
-				int tag = 2001;
-				vector<unsigned long long> MPIPos;
-				
-				MPI_Status status; 
-				MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
-				MPI_Comm_size(MPI_COMM_WORLD, &processors); 
-
-				MPI_File inMPI;
-				MPI_File outMPI;
-				MPI_File outMPIAccnos;
-				
-				int outMode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-				int inMode=MPI_MODE_RDONLY; 
-				
-				char outFilename[1024];
-				strcpy(outFilename, outputFileName.c_str());
-				
-				char outAccnosFilename[1024];
-				strcpy(outAccnosFilename, accnosFileName.c_str());
-				
-				char inFileName[1024];
-				strcpy(inFileName, fastaFileNames[s].c_str());
-
-				MPI_File_open(MPI_COMM_WORLD, inFileName, inMode, MPI_INFO_NULL, &inMPI);  //comm, filename, mode, info, filepointer
-				MPI_File_open(MPI_COMM_WORLD, outFilename, outMode, MPI_INFO_NULL, &outMPI);
-				MPI_File_open(MPI_COMM_WORLD, outAccnosFilename, outMode, MPI_INFO_NULL, &outMPIAccnos);
-				
-				if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&inMPI);  MPI_File_close(&outMPI);   MPI_File_close(&outMPIAccnos);  for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	}  delete chimera; return 0;  }
-
-				if (pid == 0) { //you are the root process 
 								
-					MPIPos = m->setFilePosFasta(fastaFileNames[s], numSeqs); //fills MPIPos, returns numSeqs
-					
-					//send file positions to all processes
-					for(int i = 1; i < processors; i++) { 
-						MPI_Send(&numSeqs, 1, MPI_INT, i, tag, MPI_COMM_WORLD);
-						MPI_Send(&MPIPos[0], (numSeqs+1), MPI_LONG, i, tag, MPI_COMM_WORLD);
-					}
-					
-					//figure out how many sequences you have to align
-					numSeqsPerProcessor = numSeqs / processors;
-					int startIndex =  pid * numSeqsPerProcessor;
-					if(pid == (processors - 1)){	numSeqsPerProcessor = numSeqs - pid * numSeqsPerProcessor; 	}
-				
-					//do your part
-					driverMPI(startIndex, numSeqsPerProcessor, inMPI, outMPI, outMPIAccnos, MPIPos);
-					
-					if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&inMPI);  MPI_File_close(&outMPI);   MPI_File_close(&outMPIAccnos);  m->mothurRemove(outputFileName);  m->mothurRemove(accnosFileName);  for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	}  delete chimera; return 0;  }
-					
-				}else{ //you are a child process
-					MPI_Recv(&numSeqs, 1, MPI_INT, 0, tag, MPI_COMM_WORLD, &status);
-					MPIPos.resize(numSeqs+1);
-					MPI_Recv(&MPIPos[0], (numSeqs+1), MPI_LONG, 0, tag, MPI_COMM_WORLD, &status);
-					
-					//figure out how many sequences you have to align
-					numSeqsPerProcessor = numSeqs / processors;
-					int startIndex =  pid * numSeqsPerProcessor;
-					if(pid == (processors - 1)){	numSeqsPerProcessor = numSeqs - pid * numSeqsPerProcessor; 	}
-					
-					//do your part
-					driverMPI(startIndex, numSeqsPerProcessor, inMPI, outMPI, outMPIAccnos, MPIPos);
-					
-					if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&inMPI);  MPI_File_close(&outMPI);   MPI_File_close(&outMPIAccnos);  for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	}  delete chimera; return 0;  }
-				}
-				
-				//close files 
-				MPI_File_close(&inMPI);
-				MPI_File_close(&outMPI);
-				MPI_File_close(&outMPIAccnos);
-				MPI_Barrier(MPI_COMM_WORLD); //make everyone wait - just in case
-		#else
-						
 			//break up file
 			#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 				vector<unsigned long long> positions = m->divideFile(fastaFileNames[s], processors);
@@ -556,8 +461,6 @@ int ChimeraPintailCommand::execute(){
 				if (m->control_pressed) { outputTypes.clear(); m->mothurRemove(outputFileName); m->mothurRemove(accnosFileName); for (int j = 0; j < outputNames.size(); j++) {	m->mothurRemove(outputNames[j]);	} for (int i = 0; i < lines.size(); i++) {  delete lines[i];  }  lines.clear(); delete chimera; return 0; }
 			#endif
 			
-		#endif	
-		
 			delete chimera;
 			for (int i = 0; i < lines.size(); i++) {  delete lines[i];  }  lines.clear();
 			
@@ -653,64 +556,6 @@ int ChimeraPintailCommand::driver(linePair* filePos, string outputFName, string
 		exit(1);
 	}
 }
-//**********************************************************************************************************************
-#ifdef USE_MPI
-int ChimeraPintailCommand::driverMPI(int start, int num, MPI_File& inMPI, MPI_File& outMPI, MPI_File& outAccMPI, vector<unsigned long long>& MPIPos){
-	try {
-				
-		MPI_Status status; 
-		int pid;
-		MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
-		
-		for(int i=0;i<num;i++){
-			
-			if (m->control_pressed) {	return 1;	}
-			
-			//read next sequence
-			int length = MPIPos[start+i+1] - MPIPos[start+i];
-	
-			char* buf4 = new char[length];
-			MPI_File_read_at(inMPI, MPIPos[start+i], buf4, length, MPI_CHAR, &status);
-			
-			string tempBuf = buf4;
-			if (tempBuf.length() > length) { tempBuf = tempBuf.substr(0, length);  }
-			istringstream iss (tempBuf,istringstream::in);
-			delete buf4;
-
-			Sequence* candidateSeq = new Sequence(iss);  m->gobble(iss);
-				
-			if (candidateSeq->getName() != "") { //incase there is a commented sequence at the end of a file
-				
-				if	(candidateSeq->getAligned().length() != templateSeqsLength) {  //chimeracheck does not require seqs to be aligned
-					m->mothurOut(candidateSeq->getName() + " is not the same length as the template sequences. Skipping."); m->mothurOutEndLine();
-				}else{
-					//find chimeras
-					chimera->getChimeras(candidateSeq);
-					
-					if (m->control_pressed) {	delete candidateSeq; return 1;	}
-		
-					//print results
-					chimera->print(outMPI, outAccMPI);
-				}
-			}
-			delete candidateSeq;
-			
-			//report progress
-			if((i+1) % 100 == 0){  cout << "Processing sequence: " << (i+1) << endl;			}
-		}
-		//report progress
-		if(num % 100 != 0){		cout << "Processing sequence: " << num << endl;	 	}
-		
-				
-		return 0;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "ChimeraPintailCommand", "driverMPI");
-		exit(1);
-	}
-}
-#endif
-
 /**************************************************************************************************/
 
 int ChimeraPintailCommand::createProcesses(string outputFileName, string filename, string accnos) {
