@@ -12,8 +12,7 @@
 
 #include "mothur.h"
 #include "command.hpp"
-#include "chimera.h"
-#include "referencedb.h"
+#include "mothurchimera.h"
 
 /***********************************************************/
 
@@ -37,22 +36,17 @@ public:
 	int execute(); 
 	void help() { m->mothurOut(getHelpString()); }		
 private:
-	ReferenceDB* rdb;
 	
 	vector<int> processIDS;   //processid
 	vector<linePair*> lines;
 	
 	int driver(linePair*, string, string, string);
 	int createProcesses(string, string, string);
-	
-	#ifdef USE_MPI
-	int driverMPI(int, int, MPI_File&, MPI_File&, MPI_File&, vector<unsigned long long>&);
-	#endif
 
 	bool abort, filter, save;
 	string fastafile, templatefile, consfile, quanfile, maskfile, outputDir, inputDir;
 	int processors, window, increment, numSeqs, templateSeqsLength;
-	Chimera* chimera;
+	MothurChimera* chimera;
 	vector<string> outputNames;
 	vector<string> fastaFileNames;
 };
