@@ -1042,7 +1042,8 @@ int ChimeraSlayerCommand::setUpForSelfReference(SequenceParser*& parser, map<str
 			fileGroup[fastaFileNames[s]] = "noGroup";
 		}else {
 			//Parse sequences by group
-			parser = new SequenceParser(groupFile, fastaFileNames[s], nameFile);
+            vector<string> temp;
+			parser = new SequenceParser(groupFile, fastaFileNames[s], nameFile, temp);
 			vector<string> groups = parser->getNamesOfGroups();
 			
 			for (int i = 0; i < groups.size(); i++) {
@@ -1088,7 +1089,8 @@ int ChimeraSlayerCommand::setUpForSelfReference(SequenceCountParser*& parser, ma
 			fileGroup[fastaFileNames[s]] = "noGroup";
 		}else {
 			//Parse sequences by group
-			parser = new SequenceCountParser(nameFile, fastaFileNames[s]);
+            vector<string> temp;
+			parser = new SequenceCountParser(nameFile, fastaFileNames[s], temp);
 			vector<string> groups = parser->getNamesOfGroups();
 			
 			for (int i = 0; i < groups.size(); i++) {
@@ -1469,9 +1471,9 @@ int ChimeraSlayerCommand::driver(linePair filePos, string outputFName, string fi
         
 		MothurChimera* chimera;
 		if (templatefile != "self") { //you want to run slayer with a reference template
-			chimera = new ChimeraSlayer(filename, templatefile, trim, search, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, blastlocation, rand());	
+			chimera = new ChimeraSlayer(filename, templatefile, trim, search, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, blastlocation, m->getRandomNumber());
 		}else {
-			chimera = new ChimeraSlayer(filename, templatefile, trim, priority, search, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, blastlocation, rand());	
+			chimera = new ChimeraSlayer(filename, templatefile, trim, priority, search, ksize, match, mismatch, window, divR, minSimilarity, minCoverage, minBS, minSNP, parents, iters, increment, numwanted, realign, blastlocation, m->getRandomNumber());	
 		}
 		
 		if (m->control_pressed) { delete chimera; return 0; }
