@@ -36,7 +36,7 @@ string DegapSeqsCommand::getHelpString(){
 		helpString += "The degap.seqs command parameter are fasta and processors.\n";
 		helpString += "The fasta parameter allows you to enter the fasta file containing your sequences, and is required unless you have a valid current fasta file. \n";
 		helpString += "You may enter multiple fasta files by separating their names with dashes. ie. fasta=abrecovery.fasta-amzon.fasta \n";
-        helpString += "The processors paramter allows you to enter the number of processors you would like to use. \n";
+        helpString += "The processors parameter allows you to enter the number of processors you would like to use. \n";
 		helpString += "The degap.seqs command should be in the following format: \n";
 		helpString += "degap.seqs(fasta=yourFastaFile) \n";	
 		helpString += "Example: degap.seqs(fasta=abrecovery.align) \n";
@@ -357,7 +357,7 @@ int DegapSeqsCommand::createProcesses(string filename, string outputFileName){
             lines.push_back(linePair(0, 1000));
         }else {
             positions = m->setFilePosFasta(filename, numSeqs);
-            if (positions.size() < processors) { processors = positions.size(); }
+            if (numSeqs < processors) { processors = numSeqs; }
             
             //figure out how many sequences you have to process
             int numSeqsPerProcessor = numSeqs / processors;
