@@ -268,6 +268,12 @@ int GetOtuLabelsCommand::execute(){
             if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setSharedFile(current); }
         }
         
+        //set constaxonomy file as new current constaxonomyfile
+        itTypes = outputTypes.find("constaxonomy");
+        if (itTypes != outputTypes.end()) {
+            if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setConsTaxonomyFile(current); }
+        }
+        
         return 0;
     }
 	catch(exception& e) {
@@ -305,7 +311,8 @@ int GetOtuLabelsCommand::readClassifyOtu(){
             string otu = ""; string tax = "unknown";
             int size = 0;
             
-            in >> otu >> size >> tax; m->gobble(in);
+            in >> otu >> size; m->gobble(in);
+            tax = m->getline(in); m->gobble(in);
             
             if (m->debug) { m->mothurOut("Otu=" + otu + ", size=" + toString(size) + ", tax=" + tax + "\n"); }
             
