@@ -805,7 +805,9 @@ vector<string> MakeBiomCommand::getMetaData(vector<SharedRAbundVector*>& lookup)
                 
                 if (m->control_pressed) { in.close(); return metadata; }
                 
-                in >> otuLabel >> size >> tax; m->gobble(in);
+                in >> otuLabel; m->gobble(in);
+                in >> size; m->gobble(in);
+                tax = m->getline(in); m->gobble(in);
                 
                 otuLabels.push_back(otuLabel);
                 taxs.push_back(tax);
@@ -920,7 +922,9 @@ vector<string> MakeBiomCommand::getMetaData(vector<SharedRAbundFloatVector*>& lo
                 
                 if (m->control_pressed) { in.close(); return metadata; }
                 
-                in >> otuLabel >> size >> tax; m->gobble(in);
+                in >> otuLabel; m->gobble(in);
+                in >> size; m->gobble(in);
+                tax = m->getline(in); m->gobble(in);
                 
                 otuLabels.push_back(otuLabel);
                 taxs.push_back(tax);
@@ -1030,11 +1034,10 @@ int MakeBiomCommand::getGreenGenesOTUIDs(vector<SharedRAbundVector*>& lookup, ma
             if (thisPos != string::npos) {
                 OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);
                 thisPos = OTUTaxonomy.find_last_of(";"); //remove rest of parent taxon
-                if (thisPos != string::npos) {
-                    OTUTaxonomy = OTUTaxonomy.substr(0, thisPos);
-                }
+                if (thisPos != string::npos) { OTUTaxonomy = OTUTaxonomy.substr(0, thisPos); }
+                OTUTaxonomy += ";";
             }
-            
+           
             //get list of reference ids that map to this taxonomy
             vector<string> referenceIds = phylo.getSeqs(OTUTaxonomy);
             
