@@ -304,129 +304,8 @@ int PairwiseSeqsCommand::execute(){
 				m->mothurRemove(outputFile);
 				outputTypes["phylip"].push_back(outputFile);
 			}
-			
-			#ifdef USE_MPI
+								
 		
-			int pid, start, end; 
-			int tag = 2001;
-					
-			MPI_Status status; 
-			MPI_Comm_size(MPI_COMM_WORLD, &processors); //set processors to the number of mpi processes running
-			MPI_Comm_rank(MPI_COMM_WORLD, &pid); //find out who we are
-			
-			//each process gets where it should start and stop in the file
-			if (output != "square") {
-				start = int (sqrt(float(pid)/float(processors)) * numSeqs);
-				end = int (sqrt(float(pid+1)/float(processors)) * numSeqs);
-			}else{
-				start = int ((float(pid)/float(processors)) * numSeqs);
-				end = int ((float(pid+1)/float(processors)) * numSeqs);
-			}
-			
-			if (output == "column") {
-				MPI_File outMPI;
-				int amode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-
-			char filename[1024];
-				strcpy(filename, outputFile.c_str());
-				
-				MPI_File_open(MPI_COMM_WORLD, filename, amode, MPI_INFO_NULL, &outMPI);
-
-				if (pid == 0) { //you are the root process 
-				
-					//do your part
-					string outputMyPart;
-					
-					driverMPI(start, end, outMPI, cutoff); 
-					
-					if (m->control_pressed) { outputTypes.clear(); MPI_File_close(&outMPI);  m->mothurRemove(outputFile); return 0; }
-				
-					//wait on chidren
-					for(int i = 1; i < processors; i++) { 
-						if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);   m->mothurRemove(outputFile);  return 0; }
-						
-						char buf[5];
-						MPI_Recv(buf, 5, MPI_CHAR, i, tag, MPI_COMM_WORLD, &status); 
-					}
-				}else { //you are a child process
-					//do your part
-					driverMPI(start, end, outMPI, cutoff); 
-					
-					if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);  m->mothurRemove(outputFile);  return 0; }
-				
-					char buf[5];
-					strcpy(buf, "done"); 
-					//tell parent you are done.
-					MPI_Send(buf, 5, MPI_CHAR, 0, tag, MPI_COMM_WORLD);
-				}
-				
-				MPI_File_close(&outMPI);
-				
-			}else { //lower triangle format
-				if (pid == 0) { //you are the root process 
-				
-					//do your part
-					string outputMyPart;
-					unsigned long long mySize;
-					
-					if (output != "square"){ driverMPI(start, end, outputFile, mySize); }
-					else { driverMPI(start, end, outputFile, mySize, output); }
-		
-					if (m->control_pressed) {  outputTypes.clear();   m->mothurRemove(outputFile);   return 0; }
-					
-					int amode=MPI_MODE_APPEND|MPI_MODE_WRONLY|MPI_MODE_CREATE; //
-					MPI_File outMPI;
-					MPI_File inMPI;
-
-					char filename[1024];
-					strcpy(filename, outputFile.c_str());
-
-					MPI_File_open(MPI_COMM_SELF, filename, amode, MPI_INFO_NULL, &outMPI);
-
-					//wait on chidren
-					for(int b = 1; b < processors; b++) { 
-						unsigned long long fileSize;
-						
-						if (m->control_pressed) { outputTypes.clear();  MPI_File_close(&outMPI);  m->mothurRemove(outputFile);   return 0; }
-						
-						MPI_Recv(&fileSize, 1, MPI_LONG, b, tag, MPI_COMM_WORLD, &status); 
-						
-						string outTemp = outputFile + toString(b) + ".temp";
-
-						char* buf = new char[outTemp.length()];
-						memcpy(buf, outTemp.c_str(), outTemp.length());
-						
-						MPI_File_open(MPI_COMM_SELF, buf, MPI_MODE_DELETE_ON_CLOSE|MPI_MODE_RDONLY, MPI_INFO_NULL, &inMPI);
-						delete buf;
-
-						int count = 0;
-						while (count < fileSize) { 
-							char buf2[1];
-							MPI_File_read(inMPI, buf2, 1, MPI_CHAR, &status);
-							MPI_File_write(outMPI, buf2, 1, MPI_CHAR, &status);
-							count += 1;
-						}
-						
-						MPI_File_close(&inMPI); //deleted on close
-					}
-					
-					MPI_File_close(&outMPI);
-				}else { //you are a child process
-					//do your part
-					unsigned long long size;
-					if (output != "square"){ driverMPI(start, end, (outputFile + toString(pid) + ".temp"), size); }
-					else { driverMPI(start, end, (outputFile + toString(pid) + ".temp"), size, output); }
-					
-					if (m->control_pressed) {  return 0; }
-				
-					//tell parent you are done.
-					MPI_Send(&size, 1, MPI_LONG, 0, tag, MPI_COMM_WORLD);
-				}
-			}
-			MPI_Barrier(MPI_COMM_WORLD); //make everyone wait - just in case
-	#else		
-					
-		//#if defined (__APPLE__) || (__MACH__) || (linux) || (__linux) || (__linux__) || (__unix__) || (__unix)
 			//if you don't need to fork anything
 			if(processors == 1){
 				if (output != "square") {  driver(0, numSeqs, outputFile, cutoff); }
@@ -447,21 +326,9 @@ int PairwiseSeqsCommand::execute(){
 				
 				createProcesses(outputFile); 
 			}
-		//#else
-			//ifstream inFASTA;
-			//if (output != "square") {  driver(0, numSeqs, outputFile, cutoff); }
-			//else { driver(0, numSeqs, outputFile, "square");  }
-		//#endif
-		
-	#endif
+
 			if (m->control_pressed) { outputTypes.clear();   m->mothurRemove(outputFile); return 0; }
 			
-			#ifdef USE_MPI
-				MPI_Comm_rank(MPI_COMM_WORLD, &pid); 
-						
-				if (pid == 0) { //only one process should output to screen
-			#endif
-			
 			ifstream fileHandle;
 			fileHandle.open(outputFile.c_str());
 			if(fileHandle) {
@@ -475,12 +342,8 @@ int PairwiseSeqsCommand::execute(){
 				system(("gzip -v " + outputFile).c_str());
 				outputNames.push_back(outputFile + ".gz");
 			}else { outputNames.push_back(outputFile); }
-			
-			#ifdef USE_MPI
-				}
-			#endif
-			
-			m->mothurOut("It took " + toString(time(NULL) - startTime) + " to calculate the distances for " + toString(numSeqs) + " sequences."); m->mothurOutEndLine();
+
+            m->mothurOut("It took " + toString(time(NULL) - startTime) + " to calculate the distances for " + toString(numSeqs) + " sequences."); m->mothurOutEndLine();
 			
 			if (m->control_pressed) { outputTypes.clear(); m->mothurRemove(outputFile); return 0; }
 		}
@@ -851,310 +714,5 @@ int PairwiseSeqsCommand::driver(int startLine, int endLine, string dFileName, st
 		exit(1);
 	}
 }
-#ifdef USE_MPI
-/**************************************************************************************************/
-/////// need to fix to work with calcs and sequencedb
-int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, MPI_File& outMPI, float cutoff){
-	try {
-		MPI_Status status;
-		int startTime = time(NULL);
-        
-        Alignment* alignment;
-        if(align == "gotoh")			{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);			}
-		else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);				}
-		else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
-		else if(align == "noalign")		{	alignment = new NoAlign();													}
-		else {
-			m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
-			m->mothurOutEndLine();
-			alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
-		}
-		
-        ValidCalculators validCalculator;
-        Dist* distCalculator;
-        if (countends) {
-            if (validCalculator.isValidCalculator("distance", Estimators[0]) == true) { 
-                if (Estimators[0] == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (Estimators[0] == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (Estimators[0] == "onegap")		{	distCalculator = new oneGapDist();	}
-            }
-        }else {
-            if (validCalculator.isValidCalculator("distance", Estimators[0]) == true) { 
-                if (Estimators[0] == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (Estimators[0] == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (Estimators[0] == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
-            }
-        }
-
-		string outputString = "";
-		
-		for(int i=startLine;i<endLine;i++){
-	
-			for(int j=0;j<i;j++){
-				
-				if (m->control_pressed) { delete alignment; delete distCalculator; return 0;  }
-				
-				if (alignDB.get(i).getUnaligned().length() > alignment->getnRows()) {
-					alignment->resize(alignDB.get(i).getUnaligned().length()+1);
-				}
-				
-				if (alignDB.get(j).getUnaligned().length() > alignment->getnRows()) {
-					alignment->resize(alignDB.get(j).getUnaligned().length()+1);
-				}
-				
-				Sequence seqI(alignDB.get(i).getName(), alignDB.get(i).getAligned());
-				Sequence seqJ(alignDB.get(j).getName(), alignDB.get(j).getAligned());
-				
-				alignment->align(seqI.getUnaligned(), seqJ.getUnaligned());
-				seqI.setAligned(alignment->getSeqAAln());
-				seqJ.setAligned(alignment->getSeqBAln());
-				
-				distCalculator->calcDist(seqI, seqJ);
-				double dist = distCalculator->getDist();
-                
-                if (m->debug) { cout << ("[DEBUG]: " + seqI.getName() + '\t' +  alignment->getSeqAAln() + '\n' + seqJ.getName() + alignment->getSeqBAln() + '\n' + "distance = " + toString(dist) + "\n"); }
-				
-				if(dist <= cutoff){
-					 outputString += (alignDB.get(i).getName() + ' ' + alignDB.get(j).getName() + ' ' + toString(dist) + '\n'); 
-				}
-			}
-			
-			if(i % 100 == 0){
-				//m->mothurOut(toString(i) + "\t" + toString(time(NULL) - startTime)); m->mothurOutEndLine();
-				cout << i << '\t' << (time(NULL) - startTime) << endl;
-			}
-			
-			 
-			//send results to parent
-			int length = outputString.length();
-
-			char* buf = new char[length];
-			memcpy(buf, outputString.c_str(), length);
-			
-			MPI_File_write_shared(outMPI, buf, length, MPI_CHAR, &status);
-			outputString = "";
-			delete buf;
-			
-		}
-		delete alignment;
-        delete distCalculator;
-		return 1;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PairwiseSeqsCommand", "driverMPI");
-		exit(1);
-	}
-}
-/**************************************************************************************************/
-/////// need to fix to work with calcs and sequencedb
-int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, string file, unsigned long long& size){
-	try {
-		MPI_Status status;
-		
-		MPI_File outMPI;
-		int amode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-
-		char filename[1024];
-		strcpy(filename, file.c_str());
-
-		MPI_File_open(MPI_COMM_SELF, filename, amode, MPI_INFO_NULL, &outMPI);
-
-		Alignment* alignment;
-        if(align == "gotoh")			{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);			}
-		else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);				}
-		else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
-		else if(align == "noalign")		{	alignment = new NoAlign();													}
-		else {
-			m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
-			m->mothurOutEndLine();
-			alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
-		}
-        
-        ValidCalculators validCalculator;
-        Dist* distCalculator;
-        if (countends) {
-            if (validCalculator.isValidCalculator("distance", Estimators[0]) == true) { 
-                if (Estimators[0] == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (Estimators[0] == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (Estimators[0] == "onegap")		{	distCalculator = new oneGapDist();	}
-            }
-        }else {
-            if (validCalculator.isValidCalculator("distance", Estimators[0]) == true) { 
-                if (Estimators[0] == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (Estimators[0] == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (Estimators[0] == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
-            }
-        }
-
-		
-		string outputString = "";
-		size = 0;
-		
-		if(startLine == 0){	outputString += toString(alignDB.getNumSeqs()) + "\n";	}
-		
-		for(int i=startLine;i<endLine;i++){
-				
-			string name = alignDB.get(i).getName();
-			if (name.length() < 10) { //pad with spaces to make compatible
-				while (name.length() < 10) {  name += " ";  }
-			}
-			outputString += name;
-			
-			for(int j=0;j<i;j++){
-				
-				if (m->control_pressed) { delete alignment; delete distCalculator; return 0;  }
-				
-				if (alignDB.get(i).getUnaligned().length() > alignment->getnRows()) {
-					alignment->resize(alignDB.get(i).getUnaligned().length()+1);
-				}
-				
-				if (alignDB.get(j).getUnaligned().length() > alignment->getnRows()) {
-					alignment->resize(alignDB.get(j).getUnaligned().length()+1);
-				}
-				
-				Sequence seqI(alignDB.get(i).getName(), alignDB.get(i).getAligned());
-				Sequence seqJ(alignDB.get(j).getName(), alignDB.get(j).getAligned());
-				
-				alignment->align(seqI.getUnaligned(), seqJ.getUnaligned());
-				seqI.setAligned(alignment->getSeqAAln());
-				seqJ.setAligned(alignment->getSeqBAln());
-				
-				distCalculator->calcDist(seqI, seqJ);
-				double dist = distCalculator->getDist();
-                
-                if (m->debug) { cout << ("[DEBUG]: " + seqI.getName() + '\t' +  alignment->getSeqAAln() + '\n' + seqJ.getName() + alignment->getSeqBAln() + '\n' + "distance = " + toString(dist) + "\n"); }
-				
-				outputString +=  + "\t" + toString(dist);
-			}
-			
-			outputString += "\n"; 
-			
-			//send results to parent
-			int length = outputString.length();
-			char* buf = new char[length];
-			memcpy(buf, outputString.c_str(), length);
-			
-			MPI_File_write(outMPI, buf, length, MPI_CHAR, &status);
-			size += outputString.length();
-			outputString = "";
-			delete buf;
-		}
-		
-		MPI_File_close(&outMPI);
-        delete alignment;
-        delete distCalculator;
-		
-		return 1;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PairwiseSeqsCommand", "driverMPI");
-		exit(1);
-	}
-}
-/**************************************************************************************************/
-/////// need to fix to work with calcs and sequencedb
-int PairwiseSeqsCommand::driverMPI(int startLine, int endLine, string file, unsigned long long& size, string square){
-	try {
-		MPI_Status status;
-		
-		MPI_File outMPI;
-		int amode=MPI_MODE_CREATE|MPI_MODE_WRONLY; 
-
-		char filename[1024];
-		strcpy(filename, file.c_str());
-
-		MPI_File_open(MPI_COMM_SELF, filename, amode, MPI_INFO_NULL, &outMPI);
-		
-		Alignment* alignment;
-        if(align == "gotoh")			{	alignment = new GotohOverlap(gapOpen, gapExtend, match, misMatch, longestBase);			}
-		else if(align == "needleman")	{	alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);				}
-		else if(align == "blast")		{	alignment = new BlastAlignment(gapOpen, gapExtend, match, misMatch);		}
-		else if(align == "noalign")		{	alignment = new NoAlign();													}
-		else {
-			m->mothurOut(align + " is not a valid alignment option. I will run the command using needleman.");
-			m->mothurOutEndLine();
-			alignment = new NeedlemanOverlap(gapOpen, match, misMatch, longestBase);
-		}
-		
-        ValidCalculators validCalculator;
-        Dist* distCalculator;
-        if (countends) {
-            if (validCalculator.isValidCalculator("distance", Estimators[0]) == true) { 
-                if (Estimators[0] == "nogaps")			{	distCalculator = new ignoreGaps();	}
-                else if (Estimators[0] == "eachgap")	{	distCalculator = new eachGapDist();	}
-                else if (Estimators[0] == "onegap")		{	distCalculator = new oneGapDist();	}
-            }
-        }else {
-            if (validCalculator.isValidCalculator("distance", Estimators[0]) == true) { 
-                if (Estimators[0] == "nogaps")		{	distCalculator = new ignoreGaps();					}
-                else if (Estimators[0] == "eachgap"){	distCalculator = new eachGapIgnoreTermGapDist();	}
-                else if (Estimators[0] == "onegap")	{	distCalculator = new oneGapIgnoreTermGapDist();		}
-            }
-        }
-        
-		string outputString = "";
-		size = 0;
-		
-		if(startLine == 0){	outputString += toString(alignDB.getNumSeqs()) + "\n";	}
-		
-		for(int i=startLine;i<endLine;i++){
-				
-			string name = alignDB.get(i).getName();
-			if (name.length() < 10) { //pad with spaces to make compatible
-				while (name.length() < 10) {  name += " ";  }
-			}
-			outputString += name;
-			
-			for(int j=0;j<alignDB.getNumSeqs();j++){
-				
-				if (m->control_pressed) {  delete alignment; return 0;  }
-				
-				if (alignDB.get(i).getUnaligned().length() > alignment->getnRows()) {
-					alignment->resize(alignDB.get(i).getUnaligned().length()+1);
-				}
-				
-				if (alignDB.get(j).getUnaligned().length() > alignment->getnRows()) {
-					alignment->resize(alignDB.get(j).getUnaligned().length()+1);
-				}
-				
-				Sequence seqI(alignDB.get(i).getName(), alignDB.get(i).getAligned());
-				Sequence seqJ(alignDB.get(j).getName(), alignDB.get(j).getAligned());
-				
-				alignment->align(seqI.getUnaligned(), seqJ.getUnaligned());
-				seqI.setAligned(alignment->getSeqAAln());
-				seqJ.setAligned(alignment->getSeqBAln());
-				
-				distCalculator->calcDist(seqI, seqJ);
-				double dist = distCalculator->getDist();
-				
-				outputString +=  + "\t" + toString(dist);
-                
-                if (m->debug) { cout << ("[DEBUG]: " + seqI.getName() + '\t' +  alignment->getSeqAAln() + '\n' + seqJ.getName() + alignment->getSeqBAln() + '\n' + "distance = " + toString(dist) + "\n"); }
-			}
-			
-			outputString += "\n"; 
-
-			//send results to parent
-			int length = outputString.length();
-			char* buf = new char[length];
-			memcpy(buf, outputString.c_str(), length);
-			
-			MPI_File_write(outMPI, buf, length, MPI_CHAR, &status);
-			size += outputString.length();
-			outputString = "";
-			delete buf;
-		}
-		
-		MPI_File_close(&outMPI);
-		
-        delete alignment;
-		return 1;
-	}
-	catch(exception& e) {
-		m->errorOut(e, "PairwiseSeqsCommand", "driverMPI");
-		exit(1);
-	}
-}
-#endif
 /**************************************************************************************************/
 
