@@ -21,33 +21,35 @@
 #include "needlemanoverlap.hpp"
 #include "blastalign.hpp"
 #include "noalign.hpp"
-
+#include "filters.h"
 
 /************************************************************/
 struct seqPNode {
 	int numIdentical;
 	Sequence seq;
+    string filteredSeq;
 	string names;
 	bool active;
 	int diffs;
 	seqPNode() {}
-	seqPNode(int n, Sequence s, string nm) : numIdentical(n), seq(s), names(nm), active(1) { diffs = 0; }
+	seqPNode(int n, Sequence s, string nm) : numIdentical(n), seq(s), names(nm), active(1) { diffs = 0; filteredSeq = "";}
 	~seqPNode() {}
 };
 /************************************************************/
 inline bool comparePriorityTopDown(seqPNode first, seqPNode second) {  
     if (first.numIdentical > second.numIdentical) { return true;  }
-    else if (first.numIdentical == second.numIdentical) { 
-        if (first.seq.getName() > second.seq.getName()) { return true; }
-    }
+    //else if (first.numIdentical == second.numIdentical) {
+        //if (first.seq.getName() > second.seq.getName()) { return true; }
+    //}
+
     return false; 
 }
 /************************************************************/
 inline bool comparePriorityDownTop(seqPNode first, seqPNode second) {  
     if (first.numIdentical < second.numIdentical) { return true;  }
-    else if (first.numIdentical == second.numIdentical) { 
-        if (first.seq.getName() > second.seq.getName()) { return true; }
-    }
+    //else if (first.numIdentical == second.numIdentical) {
+        //if (first.seq.getName() > second.seq.getName()) { return true; }
+    //}
     return false; 
 }
 //************************************************************/
@@ -83,22 +85,17 @@ private:
 	bool abort, bygroup, topdown;
 	string fastafile, namefile, outputDir, groupfile, countfile, method, align;
 	vector<seqPNode> alignSeqs; //maps the number of identical seqs to a sequence
-	map<string, string> names; //represents the names file first column maps to second column
-	map<string, int> sizes;  //this map a seq name to the number of identical seqs in the names file
-	map<string, int>::iterator itSize; 
-//	map<string, bool> active; //maps sequence name to whether it has already been merged or not.
 	vector<string> outputNames;
 	
 	int readFASTA();
-	void readNameFile();
-	//int readNamesFASTA();
 	int calcMisMatches(string, string);
 	void printData(string, string, string); //fasta filename, names file name
 	int process(string);
 	int loadSeqs(map<string, string>&, vector<Sequence>&, string);
-	int driverGroups(string, string, string, int, int, vector<string> groups);
-	int createProcessesGroups(string, string, string, vector<string>);
+	int driverGroups(string, string, string, int, int, vector<string>);
+	int createProcessesGroups(string, string, string);
     int mergeGroupCounts(string, string, string);
+    int filterSeqs();
 };
 
 /**************************************************************************************************/
@@ -166,14 +163,17 @@ static DWORD WINAPI MyPreclusterThreadFunction(LPVOID lpParam){
             alignment = new NeedlemanOverlap(pDataArray->gapOpen, pDataArray->match, pDataArray->misMatch, 1000);
         }
         
-		//parse fasta and name file by group
-		SequenceParser* parser;
+        vector<string> subsetGroups;
+        for (int i = pDataArray->start; i < pDataArray->end; i++) {  subsetGroups.push_back(pDataArray->groups[i]);  }
+        
+        //parse fasta and name file by group
         SequenceCountParser* cparser;
+        SequenceParser* parser;
         if (pDataArray->countfile != "") {
-            cparser = new SequenceCountParser(pDataArray->countfile, pDataArray->fastafile);
+            cparser = new SequenceCountParser(pDataArray->countfile, pDataArray->fastafile, subsetGroups);
         }else {
-            if (pDataArray->namefile != "") { parser = new SequenceParser(pDataArray->groupfile, pDataArray->fastafile, pDataArray->namefile);	}
-            else				{ parser = new SequenceParser(pDataArray->groupfile, pDataArray->fastafile);			}
+            if (pDataArray->namefile != "") { parser = new SequenceParser(pDataArray->groupfile, pDataArray->fastafile, pDataArray->namefile, subsetGroups);	}
+            else				{ parser = new SequenceParser(pDataArray->groupfile, pDataArray->fastafile, subsetGroups);              }
         }
         
  		int numSeqs = 0;
@@ -189,7 +189,7 @@ static DWORD WINAPI MyPreclusterThreadFunction(LPVOID lpParam){
             
 			int start = time(NULL);
 			
-            if (pDataArray->m->control_pressed) {  delete parser; delete alignment;return 0; }
+            if (pDataArray->m->control_pressed) { if (pDataArray->countfile != "") { delete cparser; } else { delete parser; } delete alignment;return 0; }
 			
 			pDataArray->m->mothurOutEndLine(); pDataArray->m->mothurOut("Processing group " + pDataArray->groups[k] + ":"); pDataArray->m->mothurOutEndLine();
 			
@@ -250,10 +250,38 @@ static DWORD WINAPI MyPreclusterThreadFunction(LPVOID lpParam){
 				}
 			}
 			
-            if (lengths.size() > 1) { pDataArray->method = "unaligned"; }
-            else if (lengths.size() == 1) {  pDataArray->method = "aligned"; }
-            
             length = *(lengths.begin());
+            
+            if (lengths.size() > 1) { pDataArray->method = "unaligned"; }
+            else if (lengths.size() == 1) {
+                pDataArray->method = "aligned";
+                ////////////////////////////////////////////////////
+                //filterSeqs();
+                
+                string filterString = "";
+                Filters F;
+                
+                F.setLength(length);
+                F.initialize();
+                F.setFilter(string(length, '1'));
+                
+                for (int i = 0; i < alignSeqs.size(); i++) { F.getFreqs(alignSeqs[i].seq);}
+                
+                F.setNumSeqs(alignSeqs.size());
+                F.doVerticalAllBases();
+                filterString = F.getFilter();
+                
+                //run filter
+                for (int i = 0; i < alignSeqs.size(); i++) {
+                    alignSeqs[i].filteredSeq = "";
+                    string align = alignSeqs[i].seq.getAligned();
+                    for(int j=0;j<length;j++){
+                        if(filterString[j] == '1'){ alignSeqs[i].filteredSeq += align[j]; }
+                    }
+                }
+                ////////////////////////////////////////////////////
+            }
+            
 			//sanity check
 			if (error) { pDataArray->m->control_pressed = true; }
 			
@@ -323,9 +351,9 @@ static DWORD WINAPI MyPreclusterThreadFunction(LPVOID lpParam){
                                         if (mismatch > pDataArray->diffs) { mismatch = length; break;  } //to far to cluster
                                     }
                                 }else {
-                                    for (int k = 0; k < alignSeqs[i].seq.getAligned().length(); k++) {
+                                    for (int k = 0; k < alignSeqs[i].filteredSeq.length(); k++) {
                                         //do they match
-                                        if (alignSeqs[i].seq.getAligned()[k] != alignSeqs[j].seq.getAligned()[k]) { mismatch++; }
+                                        if (alignSeqs[i].filteredSeq[k] != alignSeqs[j].filteredSeq[k]) { mismatch++; }
                                         if (mismatch > pDataArray->diffs) { mismatch = length; break; } //to far to cluster
                                     }
                                 }
@@ -396,9 +424,9 @@ static DWORD WINAPI MyPreclusterThreadFunction(LPVOID lpParam){
                                 }
                             }else {
 
-                                for (int k = 0; k < alignSeqs[i].seq.getAligned().length(); k++) {
+                                for (int k = 0; k < alignSeqs[i].filteredSeq.length(); k++) {
                                     //do they match
-                                    if (alignSeqs[i].seq.getAligned()[k] != alignSeqs[j].seq.getAligned()[k]) { mismatch++; }
+                                    if (alignSeqs[i].filteredSeq[k] != alignSeqs[j].filteredSeq[k]) { mismatch++; }
                                     if (mismatch > pDataArray->diffs) { mismatch = length; break; } //to far to cluster
                                 }
                             }
