@@ -1049,8 +1049,8 @@ int RemoveGroupsCommand::readTax(){
 		while(!in.eof()){
 			if (m->control_pressed) { in.close();  out.close();  m->mothurRemove(outputFileName);  return 0; }
 			
-			in >> name;				//read from first column
-			in >> tax;			//read from second column
+            in >> name; m->gobble(in);
+            tax = m->getline(in); m->gobble(in);
 			
 			//if this name is in the accnos file
 			if (names.count(name) == 0) {
@@ -1062,8 +1062,6 @@ int RemoveGroupsCommand::readTax(){
 					wroteSomething = true;
 					out << it->second << '\t' << tax << endl;
 				}else { removedCount++; }  }
-			
-			m->gobble(in);
 		}
 		in.close();
 		out.close();
