@@ -416,6 +416,12 @@ int RemoveLineageCommand::execute(){
 			if (itTypes != outputTypes.end()) {
 				if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setCountTableFile(current); }
 			}
+            
+            //set constaxonomy file as new current constaxonomyfile
+            itTypes = outputTypes.find("constaxonomy");
+            if (itTypes != outputTypes.end()) {
+                if ((itTypes->second).size() != 0) { current = (itTypes->second)[0]; m->setConsTaxonomyFile(current); }
+            }
 		}
 		
 		return 0;		
@@ -1070,9 +1076,9 @@ int RemoveLineageCommand::readTax(){
 
 			if (m->control_pressed) { in.close(); out.close(); m->mothurRemove(outputFileName);  return 0; }
 
-			in >> name;				//read from first column
-			in >> tax;			//read from second column
-			
+            in >> name; m->gobble(in);
+            tax = m->getline(in); m->gobble(in);
+            
 			bool remove = false;
 			
             string noQuotesTax = m->removeQuotes(tax);
@@ -1176,7 +1182,6 @@ int RemoveLineageCommand::readTax(){
 			}
 			
 			if (!remove) {  wroteSomething = true; out << name << '\t' << tax << endl; }
-			m->gobble(in);
 		}
 		in.close();
 		out.close();
@@ -1237,7 +1242,7 @@ int RemoveLineageCommand::readConsTax(){
             
 			in >> otuLabel;	 		m->gobble(in);
             in >> numReps;          m->gobble(in);
-			in >> tax;              m->gobble(in);
+			tax = m->getline(in);   m->gobble(in);
 			
             bool remove = false;
 			
