@@ -59,8 +59,8 @@ string RenameFileCommand::getHelpString(){
     try {
         string helpString = "";
         helpString += "The rename.file command allows you to rename files and updates the current files saved by mothur.\n";
-        helpString += "The rename.file command parameters are: phylip, column, list, rabund, sabund, name, group, design, tree, shared, relabund, fasta, qfile, sff, oligos, accnos, biom, count, summary, file, taxonomy, constaxonomy, input, output, prefix, deletedold and shorten.\n";
-        helpString += "The output parameter allows you to provide an output file name for the input file you provide.\n";
+        helpString += "The rename.file command parameters are: phylip, column, list, rabund, sabund, name, group, design, tree, shared, relabund, fasta, qfile, sff, oligos, accnos, biom, count, summary, file, taxonomy, constaxonomy, input, new, prefix, deletedold and shorten.\n";
+        helpString += "The new parameter allows you to provide an output file name for the input file you provide.\n";
         helpString += "The shorten parameter is used to inicate you want mothur to generate output file names for you. For example: stability.trim.contigs.good.unique.good.filter.unique.precluster.pick.pick.pick.an.unique_list.shared would become stability.an.shared. Default=true.";
         helpString += "The prefix parameter allows you to enter your own prefix for shortened names.";
         helpString += "The deleteold parameter indicates whether you want to delete the old file.  Default=true.";
@@ -463,13 +463,14 @@ RenameFileCommand::RenameFileCommand(string option)  {
             temp = validParameter.validFile(parameters, "deleteold", false);		if (temp == "not found") { temp = "T"; }
             deleteOld = m->isTrue(temp);
             
-            prefix = validParameter.validFile(parameters, "prefix", false);		if (prefix == "not found") { temp = ""; }
+            prefix = validParameter.validFile(parameters, "prefix", false);		if (prefix == "not found") { prefix = ""; }
             
             outputfile = validParameter.validFile(parameters, "new", false);
             if (outputfile == "not found") {
                 if (!mothurGenerated) { m->mothurOut("[ERROR]: you must enter an output file name"); m->mothurOutEndLine();  abort=true; }
                 outputfile = "";
-            }else if (outputDir != "") { outputfile = outputDir + m->getSimpleName(outputfile);  }
+            }else { mothurGenerated=false; if (outputDir != "") { outputfile = outputDir + m->getSimpleName(outputfile);  } }
+            
             
             if ((!mothurGenerated) && (numFiles > 1)) {
                 m->mothurOut("[ERROR]: You cannot use more than one file parameter unless mothur is generating the output filenames for you.\n"); abort= true;
@@ -478,6 +479,8 @@ RenameFileCommand::RenameFileCommand(string option)  {
             if ((mothurGenerated) && (outputfile != "") && (numFiles != 1)) {
                 m->mothurOut("[ERROR]: You must allow mothur to generate the filenames or input one file at a time with a new name, not both.\n"); abort= true;
             }
+            
+            if (outputDir != "") { outputfile = outputDir + m->getSimpleName(outputfile);  }
         }
         
     }
@@ -584,7 +587,7 @@ int RenameFileCommand::execute(){
         if (constaxonomyfile != "") {
             newName = getNewName(constaxonomyfile, "constaxonomy");
             renameOrCopy(constaxonomyfile, newName);
-            m->setTaxonomyFile(newName);
+            m->setConsTaxonomyFile(newName);
         }
         if (flowfile != "") {
             newName = getNewName(flowfile, "flow");
@@ -632,6 +635,7 @@ int RenameFileCommand::execute(){
 string RenameFileCommand::getNewName(string name, string type){
     try {
         string newName = outputfile;
+        name = m->getFullPathName(name);
         
         if (mothurGenerated) {
             string extension = m->getExtension(name);
@@ -644,12 +648,15 @@ string RenameFileCommand::getNewName(string name, string type){
             }else { basicName = prefix; }
             
             if ((type == "shared") || (type == "list") || (type == "relabund") || (type == "rabund") || (type == "sabund")) {
-                vector<string> tags; tags.push_back(".an."); tags.push_back(".tx.");  tags.push_back(".agc."); tags.push_back(".dgc."); tags.push_back(".nn."); tags.push_back(".fn."); tags.push_back(".wn.");
-                vector<string> newTags; newTags.push_back("an"); newTags.push_back("tx");  newTags.push_back("agc"); newTags.push_back("dgc"); newTags.push_back("nn"); newTags.push_back("fn"); newTags.push_back("wn");
+                vector<string> tags; tags.push_back(".an."); tags.push_back(".tx.");  tags.push_back(".agc."); tags.push_back(".dgc."); tags.push_back(".nn."); tags.push_back(".fn."); tags.push_back(".wn."); tags.push_back(".opti_");
                 
                 for (int i = 0; i < tags.size(); i++) {
-                    int pos2 = name.find_first_of(tags[i]);
-                    if (pos2 != string::npos) { tag = newTags[i]; break; }
+                    int pos2 = name.find(tags[i]);
+                    if (pos2 != string::npos) {
+                        int pos3 = name.substr(pos2+1).find_first_of('.');
+                        tag = name.substr(pos2+1, pos3);
+                        break;
+                    }
                 }
             }else if (type == "constaxonomy") {
                 extension = ".cons.taxonomy";
