@@ -20,7 +20,6 @@ vector<string> SensSpecCommand::setParameters(){
 		CommandParameter plabel("label", "String", "", "", "", "", "","",false,false); parameters.push_back(plabel);
 		CommandParameter pcutoff("cutoff", "Number", "", "-1.00", "", "", "","",false,false); parameters.push_back(pcutoff);
 		CommandParameter pprecision("precision", "Number", "", "100", "", "", "","",false,false); parameters.push_back(pprecision);
-		CommandParameter phard("hard", "Boolean", "", "T", "", "", "","",false,false); parameters.push_back(phard);
 		CommandParameter pseed("seed", "Number", "", "0", "", "", "","",false,false); parameters.push_back(pseed);
         CommandParameter pinputdir("inputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(pinputdir);
 		CommandParameter poutputdir("outputdir", "String", "", "", "", "", "","",false,false); parameters.push_back(poutputdir);
@@ -223,13 +222,6 @@ SensSpecCommand::SensSpecCommand(string option)  {
 				outputDir += m->hasPath(listFile); //if user entered a file with a path then preserve it
 			}
 
-			//check for optional parameter and set defaults
-			// ...at some point should added some additional type checking...
-			temp = validParameter.validFile(parameters, "hard", false);
-			if (temp == "not found"){	hard = 1;	}
-			else if(!m->isTrue(temp))	{	hard = 0;	}
-			else if(m->isTrue(temp))	{	hard = 1;	}
-
 			temp = validParameter.validFile(parameters, "cutoff", false);		if (temp == "not found") { temp = "-1.00"; }
 			m->mothurConvert(temp, cutoff);
 
@@ -298,19 +290,20 @@ int SensSpecCommand::execute(){
 
 //***************************************************************************************************************
 
-int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool& getCutoff, string& origCutoff){
+int SensSpecCommand::process(ListVector*& list, bool& getCutoff, string& origCutoff){
 
 	try {
 
 		string label = list->getLabel();
-		int numSeqs = list->getNumSeqs();
+		long long numSeqs = list->getNumSeqs();
 		int numOTUs = list->getNumBins();
 
 		if(getCutoff == 1){
 			if(label != "unique"){
 				origCutoff = label;
 				convert(label, cutoff);
-				if(!hard){	cutoff += (0.49 / double(precision));	}
+        cutoff = m->ceilDist(cutoff, precision);
+        origCutoff = toString(m->ceilDist(cutoff, precision));
 			}
 			else{
 				origCutoff = "unique";
@@ -323,7 +316,7 @@ int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool&
 		trueNegatives = 0;
 		falseNegatives = 0;
 
-		map<string, double> distanceMap;
+		set<string> distanceMap;
 
 		//could segfault out if there are sequences in phylip-formatted distance
 		//matrix that aren't in the list file
@@ -334,23 +327,21 @@ int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool&
 			int pNumSeqs;
 			phylipFile >> pNumSeqs;
 
-			double distance;
+            double distance; string name;
 
-			vector<string> seqNameVector(pNumSeqs);
+            vector<string> seqNameVector;
 			m->mothurOut(label); m->mothurOutEndLine();
 
 			for(int i=0;i<pNumSeqs;i++){
 
 				if (m->control_pressed) { return 0; }
 
-				phylipFile >> seqNameVector[i];
-
-				//otuIndices[i] = seqMap[seqName];
+                phylipFile >> name; seqNameVector.push_back(name);
 
 				for(int j=0;j<i;j++){
 					phylipFile >> distance;
 
-					if(distance <= cutoff){
+					if(distance < cutoff){
 
 						string seqNamePair;
 						if(seqNameVector[i] < seqNameVector[j]){
@@ -359,7 +350,7 @@ int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool&
 							seqNamePair = seqNameVector[j] + '-' + seqNameVector[i];
 						}
 
-						distanceMap[seqNamePair] = distance;
+						distanceMap.insert(seqNamePair);
 					}
 				}
 
@@ -380,20 +371,20 @@ int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool&
 				columnFile >> seqNameA >> seqNameB >> distance;
 				m->gobble(columnFile);
 
-				if(distance <= cutoff){
+				if(distance < cutoff){
 					string seqNamePair;
 
-					if(seqNameA < seqNameB){
+					if(seqNameA <= seqNameB){
 						seqNamePair = seqNameA + '-' + seqNameB;
 					} else {
 						seqNamePair = seqNameB + '-' + seqNameA;
 					}
-					distanceMap[seqNamePair] = distance;
+                    distanceMap.insert(seqNamePair);
 				}
 			}
 			columnFile.close();
 		}
-
+        //cout << distanceMap.size() << endl;;
 		for(int otu=0;otu<numOTUs;otu++){
 			if (m->control_pressed) { return 0; }
 
@@ -401,19 +392,8 @@ int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool&
 			string seqList = list->get(otu);
 
 			//count number of sequences in the bin
-			int nSeqsInOTU = 1;
-			for(int i=0;i<seqList.length();i++){
-				if(seqList[i] == ','){	nSeqsInOTU++;	}
-			}
-
-			string seqName = "";
-			istringstream seqListStream(seqList);
-
-			int index = 0;
-			vector<string> otuVector(nSeqsInOTU);
-			while(getline(seqListStream, seqName, ',')) {
-				otuVector[index++] = seqName;
-			}
+            vector<string> otuVector;
+			m->splitAtComma(seqList, otuVector);
 
 			// indicate that a pair of sequences are in the same OTU; will
 			// assume that if they don't show up in the map that they're in
@@ -428,7 +408,7 @@ int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool&
 						seqNamePair = otuVector[j] + '-' + otuVector[i];
 					}
 
-					map<string, double>::iterator it = distanceMap.find(seqNamePair);
+					set<string>::iterator it = distanceMap.find(seqNamePair);
 
 					if(it != distanceMap.end()){
 						truePositives++;
@@ -439,6 +419,8 @@ int SensSpecCommand::process(map<string, int>& seqMap, ListVector*& list, bool&
 				}
 			}
 		}
+        
+        //cout << *(distanceMap.begin()) << endl;
 		falseNegatives = distanceMap.size();
 		trueNegatives = numSeqs * (numSeqs-1)/2 - (falsePositives + falseNegatives + truePositives);
 
@@ -459,11 +441,9 @@ int SensSpecCommand::processListFile(){
 
 		string origCutoff = "";
 		bool getCutoff = 0;
-		if(cutoff == -1.00)	{	getCutoff = 1;															}
-		else if( !hard )	{	origCutoff = toString(cutoff);	cutoff += (0.49 / double(precision));	}
-		else 				{	origCutoff = toString(cutoff);	}
 
-		map<string, int> seqMap;
+		if(cutoff == -1.00)	{	getCutoff = 1;                                          }
+		else 				{	origCutoff = toString(m->ceilDist(cutoff, precision));	}
 
 		InputData input(listFile, "list");
 		ListVector* list = input.getListVector();
@@ -483,7 +463,7 @@ int SensSpecCommand::processListFile(){
 
 				//process
 				// int numSeqs = fillSeqMap(seqMap, list);
-				process(seqMap, list, getCutoff, origCutoff);
+				process(list, getCutoff, origCutoff);
 			}
 
 			if ((m->anyLabelsToProcess(list->getLabel(), userLabels, "") == true) && (processedLabels.count(lastLabel) != 1)) {
@@ -498,7 +478,7 @@ int SensSpecCommand::processListFile(){
 
 				//process
 				//int numSeqs = fillSeqMap(seqMap, list);
-				process(seqMap, list, getCutoff, origCutoff);
+				process(list, getCutoff, origCutoff);
 
 				//restore real lastlabel to save below
 				list->setLabel(saveLabel);
@@ -529,7 +509,7 @@ int SensSpecCommand::processListFile(){
 
 			//process
 			//int numSeqs = fillSeqMap(seqMap, list);
-			process(seqMap, list, getCutoff, origCutoff);
+			process(list, getCutoff, origCutoff);
 
 			delete list;
 		}
@@ -563,25 +543,25 @@ void SensSpecCommand::setUpOutput(){
 
 void SensSpecCommand::outputStatistics(string label, string cutoff){
 	try{
-		double tp = (double) truePositives;
-		double fp = (double) falsePositives;
-		double tn = (double) trueNegatives;
-		double fn = (double) falseNegatives;
+		long long tp =  truePositives;
+		long long fp =  falsePositives;
+		long long tn =  trueNegatives;
+		long long fn =  falseNegatives;
 
-		double p = tp + fn;
-		double n = fp + tn;
-		double pPrime = tp + fp;
-		double nPrime = tn + fn;
+		long long p = tp + fn;
+		long long n = fp + tn;
+		long long pPrime = tp + fp;
+		long long nPrime = tn + fn;
 
-		double sensitivity = tp / p;
-		double specificity = tn / n;
-		double positivePredictiveValue = tp / pPrime;
-		double negativePredictiveValue = tn / nPrime;
-		double falseDiscoveryRate = fp / pPrime;
+		double sensitivity = tp / (double) p;
+		double specificity = tn / (double)n;
+		double positivePredictiveValue = tp / (double)pPrime;
+		double negativePredictiveValue = tn / (double)nPrime;
+		double falseDiscoveryRate = fp / (double)pPrime;
 
-		double accuracy = (tp + tn) / (p + n);
-		double matthewsCorrCoef = (tp * tn - fp * fn) / sqrt(p * n * pPrime * nPrime);	if(p == 0 || n == 0){	matthewsCorrCoef = 0;	}
-		double f1Score = 2.0 * tp / (p + pPrime);
+		double accuracy = (tp + tn) / (double)(p + n);
+		double matthewsCorrCoef = (tp * tn - fp * fn) / (double)sqrt(p * n * pPrime * nPrime);	if(p == 0 || n == 0){	matthewsCorrCoef = 0;	}
+		double f1Score = 2.0 * tp / (double)(p + pPrime);
 
 
 		if(p == 0)			{	sensitivity = 0;	matthewsCorrCoef = 0;	}
