@@ -48,7 +48,7 @@ vector<string> SffInfoCommand::setParameters(){
 string SffInfoCommand::getHelpString(){	
 	try {
 		string helpString = "";
-		helpString += "The sffinfo command reads a sff file and extracts the sequence data, or you can use it to parse a sfftxt file.\n";
+		helpString += "The sffinfo command reads a sff file and extracts the sequence data, or you can use it to parse a sff file.\n";
 		helpString += "The sffinfo command parameters are sff, fasta, qfile, accnos, flow, sfftxt, oligos, group, bdiffs, tdiffs, ldiffs, sdiffs, pdiffs, checkorient and trim. sff is required. \n";
 		helpString += "The sff parameter allows you to enter the sff file you would like to extract data from.  You may enter multiple files by separating them by -'s.\n";
 		helpString += "The fasta parameter allows you to indicate if you would like a fasta formatted file generated.  Default=True. \n";
@@ -1383,6 +1383,8 @@ int SffInfoCommand::findGroup(Header header, seqRead read, int& barcode, int& pr
         int currentSeqsDiffs = 0;
         
         string seq = read.bases;
+
+        for (int i = 0; i < seq.length(); i++) { seq[i] = toupper(seq[i]); }
         
         if (trim) {
             if(header.clipQualRight < header.clipQualLeft){
@@ -1398,16 +1400,6 @@ int SffInfoCommand::findGroup(Header header, seqRead read, int& barcode, int& pr
             else {
                 seq = seq.substr(header.clipQualLeft-1);
             }
-        }else{
-            //if you wanted the sfftxt then you already converted the bases to the right case
-            if (!sfftxt) {
-                int endValue = header.clipQualRight;
-                //make the bases you want to clip lowercase and the bases you want to keep upper case
-                if(endValue == 0){	endValue = seq.length();	}
-                for (int i = 0; i < (header.clipQualLeft-1); i++) { seq[i] = tolower(seq[i]);  }
-                for (int i = (header.clipQualLeft-1); i < (endValue-1); i++)  {   seq[i] = toupper(seq[i]);  }
-                for (int i = (endValue-1); i < seq.length(); i++) {   seq[i] = tolower(seq[i]);  }
-            }
         }
         
         Sequence currSeq(header.name, seq);
