@@ -476,6 +476,8 @@ int SharedCommand::createSharedFromBiom() {
 
             //read data
             vector<SharedRAbundVector*> lookup = readData(matrixFormat, thisLine, matrixElementType, groupNames, otuNames.size());
+            
+            eliminateZeroOTUS(lookup);
 
             m->mothurOutEndLine(); m->mothurOut(lookup[0]->getLabel()); m->mothurOutEndLine();
             lookup[0]->printHeaders(out);
@@ -527,7 +529,7 @@ vector<SharedRAbundVector*> SharedCommand::readData(string matrixFormat, string
                     inBrackets = false;
                     int temp;
                     float temp2;
-                    if (matrixElementType == "float") { m->mothurConvert(num, temp2); temp = (int)temp2; }
+                    if (matrixElementType == "float") { m->mothurConvert(num, temp2); temp = floor(temp2); }
                     else { m->mothurConvert(num, temp); }
                     nums.push_back(temp);
                     num = "";
@@ -556,7 +558,9 @@ vector<SharedRAbundVector*> SharedCommand::readData(string matrixFormat, string
                 if (inBrackets) {
                     if (line[i] == ',') {
                         int temp;
-                        m->mothurConvert(num, temp);
+                        float temp2;
+                        if (matrixElementType == "float") { m->mothurConvert(num, temp2); temp = floor(temp2); }
+                        else { m->mothurConvert(num, temp); }
                         nums.push_back(temp);
                         num = "";
                     }else { if (!isspace(line[i])) { num += line[i]; }  }
