@@ -199,6 +199,9 @@ int SparccCommand::execute(){
         vector<SharedRAbundVector*> lookup = input.getSharedRAbundVectors();
         string lastLabel = lookup[0]->getLabel();
         
+        int numOTUs = lookup[0]->getNumBins();
+        if (numOTUs >= maxIterations) {  m->mothurOut("[WARNING]: The number of iterations is set higher than the number of OTUs, reducing to " + toString(numOTUs-1) + "\n"); maxIterations = numOTUs-1; }
+        
         //if the users enters label "0.06" and there is no "0.06" in their file use the next lowest label.
         set<string> processedLabels;
         set<string> userLabels = labels;
@@ -300,7 +303,7 @@ vector<vector<float> > SparccCommand::shuffleSharedVector(vector<vector<float> >
         
         for(int i=0;i<numGroups;i++){
             for(int j=0;j<numOTUs;j++){
-                shuffledVector[i][j] = sharedVector[rand()%numGroups][j];
+                shuffledVector[i][j] = sharedVector[m->getRandomIndex(numGroups-1)][j];
             }
         }
         
@@ -607,7 +610,6 @@ vector<vector<float> > SparccCommand::createProcesses(vector<vector<float> >& sh
 		exit(1);
 	}
 }
-
 //**********************************************************************************************************************
 vector<vector<float> > SparccCommand::driver(vector<vector<float> >& sharedVector, vector<vector<float> >& origCorrMatrix, int numPerms){
 	try {
@@ -631,7 +633,9 @@ vector<vector<float> > SparccCommand::driver(vector<vector<float> >& sharedVecto
                     else if(observedValue < 0 && randValue < observedValue){ pValues[j][k]++; }//pvalues of small rho values
                 }
             }
-            if((i+1) % (int)(numPermutations * 0.05) == 0){ cout << i+1 << endl;  }
+            
+            float done = ceil(numPermutations * 0.05);
+            if((i+1) % (int)(done) == 0){ cout << i+1 << endl;  }
         }
         
         return pValues;
