@@ -20,7 +20,7 @@ class AlignmentDB {
 
 public:
 
-	AlignmentDB(string, string, int, float, float, float, float, int);  //reads fastafile passed in and stores sequences
+	AlignmentDB(string, string, int, float, float, float, float, int, bool);  //reads fastafile passed in and stores sequences
 	AlignmentDB(string);
 	~AlignmentDB();
 	
