@@ -67,6 +67,7 @@ int DesignMap::read(string file) {
         //file without headers, fix it
         if (temp != "group") {
             group = temp;
+            m->checkGroupName(group);
             if (m->debug) { m->mothurOut("[DEBUG]: group = " + group + "\n"); }
             
             //if group info, then read it
@@ -74,6 +75,7 @@ int DesignMap::read(string file) {
             for (int i = 0; i < numCategories; i++) {
                 int thisIndex = indexCategoryMap[originalGroupIndexes[i]]; //find index of this category because we sort the values.
                 string temp = tempColumnHeaders[i];
+                m->checkGroupName(temp);
                 categoryValues[thisIndex] = temp;
             
                 if (m->debug) { m->mothurOut("[DEBUG]: value = " + temp + "\n"); }
@@ -101,7 +103,8 @@ int DesignMap::read(string file) {
             
             if (m->control_pressed) { break; }
             
-            in >> group; m->gobble(in); 
+            in >> group; m->gobble(in);
+            m->checkGroupName(group);
             if (m->debug) { m->mothurOut("[DEBUG]: group = " + group + "\n"); }
             
             //if group info, then read it
@@ -110,6 +113,7 @@ int DesignMap::read(string file) {
                 int thisIndex = indexCategoryMap[originalGroupIndexes[i]]; //find index of this category because we sort the values.
                 string temp = "not found";
                 in >> temp; categoryValues[thisIndex] = temp; m->gobble(in);
+                m->checkGroupName(temp);
                 
                 if (m->debug) { m->mothurOut("[DEBUG]: value = " + temp + "\n"); }
                 
@@ -231,6 +235,7 @@ string DesignMap::get(string groupName, string categoryName) {
 //add group, assumes order is correct
 int DesignMap::push_back(string group, vector<string> values) {
     try {
+        m->checkGroupName(group);
         map<string, int>::iterator it = indexGroupNameMap.find(group);
         if (it == indexGroupNameMap.end()) {
             if (values.size() != getNumCategories()) {  m->mothurOut("[ERROR]: Your design file has a " + toString(getNumCategories()) + " categories and " + group + " has " + toString(values.size()) + ", please correct."); m->mothurOutEndLine(); m->control_pressed = true;  return 0; }
@@ -288,7 +293,7 @@ int DesignMap::setValues(string group, map<string, string> values) {
         return 0;
     }
 	catch(exception& e) {
-		m->errorOut(e, "DesignMap", "set");
+		m->errorOut(e, "DesignMap", "setValues");
 		exit(1);
 	}
 }
@@ -314,22 +319,21 @@ int DesignMap::getNumUnique(map<string, vector<string> > selected) {
     try {
         int num = 0;
         
-        //get indexes of categories
-        vector<int> indexes;
+        map<int, vector<string> > indexes;
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
                 m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return 0;
-            }else { indexes.push_back(it2->second); }
+            }else {
+                indexes[it2->second] = it->second;
+            }
         }
         
-        for (int i = 0; i < designMap.size(); i++) {
+        for (int j = 0; j < designMap.size(); j++) {
             bool hasAll = true; //innocent til proven guilty
-            int count = 0;
-            for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) { //loop through each
-                //check category to see if this group meets the requirements
-                if (!m->inUsersGroups(designMap[i][indexes[count]], it->second)) { hasAll = false; it = selected.end(); }
-                count++;
+            for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
+               //column number is it->first
+                if (!m->inUsersGroups(designMap[j][it->first], it->second)) { hasAll = false;  }
             }
             if (hasAll) { num++; }
         }
@@ -348,26 +352,24 @@ int DesignMap::getNumShared(map<string, vector<string> > selected) {
     try {
         int num = 0;
         
-        //get indexes of categories
-        vector<int> indexes;
+        map<int, vector<string> > indexes;
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
                 m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return 0;
-            }else { indexes.push_back(it2->second); }
+            }else {
+                indexes[it2->second] = it->second;
+            }
         }
         
-        for (int i = 0; i < designMap.size(); i++) {
-            bool hasAny = false; //guilty til proven innocent
-            int count = 0;
-            for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) { //loop through each
-                //check category to see if this group meets the requirements
-                if (m->inUsersGroups(designMap[i][indexes[count]], it->second)) { hasAny = true; it = selected.end(); }
-                count++;
+        for (int j = 0; j < designMap.size(); j++) {
+            bool hasAny = false; //innocent til proven guilty
+            for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
+                //column number is it->first
+                if (m->inUsersGroups(designMap[j][it->first], it->second)) { hasAny = true;  }
             }
             if (hasAny) { num++; }
         }
-
         
         return num;
     }
@@ -384,13 +386,14 @@ vector<string> DesignMap::getNamesUnique(map<string, vector<string> > selected)
     try {
         vector<string> names;
         
-        //get indexes of categories
-        vector<int> indexes;
+        map<int, vector<string> > indexes;
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
                 m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
-            }else { indexes.push_back(it2->second); }
+            }else {
+                indexes[it2->second] = it->second;
+            }
         }
         
         //map int to name
@@ -399,22 +402,19 @@ vector<string> DesignMap::getNamesUnique(map<string, vector<string> > selected)
             reverse[it->second] = it->first;
         }
         
-        for (int i = 0; i < designMap.size(); i++) {
+        for (int j = 0; j < designMap.size(); j++) {
             bool hasAll = true; //innocent til proven guilty
-            int count = 0;
-            for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) { //loop through each
-                //check category to see if this group meets the requirements
-                if (!m->inUsersGroups(designMap[i][indexes[count]], it->second)) { hasAll = false; it = selected.end(); }
-                count++;
+            for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
+                //column number is it->first
+                if (!m->inUsersGroups(designMap[j][it->first], it->second)) { hasAll = false;  }
             }
             if (hasAll) {
-                map<int, string>::iterator it = reverse.find(i);
+                map<int, string>::iterator it = reverse.find(j);
                 if (it == reverse.end()) {
                     m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
                 }else { names.push_back(it->second); }
             }
         }
-
         
         return names;
     }
@@ -430,13 +430,14 @@ vector<string> DesignMap::getNamesShared(map<string, vector<string> > selected)
     try {
         vector<string> names;
         
-        //get indexes of categories
-        vector<int> indexes;
+        map<int, vector<string> > indexes;
         for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) {
             map<string, int>::iterator it2 = indexCategoryMap.find(it->first);
             if (it2 == indexCategoryMap.end()) {
                 m->mothurOut("[ERROR]: Your design file does not contain a category named " + it->first + ". Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
-            }else { indexes.push_back(it2->second); }
+            }else {
+                indexes[it2->second] = it->second;
+            }
         }
         
         //map int to name
@@ -445,23 +446,21 @@ vector<string> DesignMap::getNamesShared(map<string, vector<string> > selected)
             reverse[it->second] = it->first;
         }
         
-        for (int i = 0; i < designMap.size(); i++) {
-            bool hasAny = false; 
-            int count = 0;
-            for (map<string, vector<string> >::iterator it = selected.begin(); it != selected.end(); it++) { //loop through each
-                //check category to see if this group meets the requirements
-                if (m->inUsersGroups(designMap[i][indexes[count]], it->second)) { hasAny = true; break; }
-                count++;
+        for (int j = 0; j < designMap.size(); j++) {
+            bool hasAny = false; //innocent til proven guilty
+            for (map<int, vector<string> >::iterator it = indexes.begin(); it != indexes.end(); it++) {
+                //column number is it->first
+                if (m->inUsersGroups(designMap[j][it->first], it->second)) { hasAny = true;  }
             }
+
             if (hasAny) {
-                map<int, string>::iterator it = reverse.find(i);
+                map<int, string>::iterator it = reverse.find(j);
                 if (it == reverse.end()) {
                     m->mothurOut("[ERROR]: should never get here, oops. Please correct."); m->mothurOutEndLine(); m->control_pressed = true; return names;
                 }else { names.push_back(it->second); }
             }
         }
         
-        
         return names;
     }
 	catch(exception& e) {
