@@ -21,6 +21,32 @@
 /************************************************************/
  GroupMap::~GroupMap(){}
 /************************************************************/
+int GroupMap::addSeq(string name, string group) {
+    try {
+        int error = 0;
+        
+        m->checkGroupName(group);
+        setNamesOfGroups(group);
+        
+        if (m->debug) { m->mothurOut("[DEBUG]: name = '" + name + "', group = '" + group + "'\n"); }
+        m->checkName(name);
+        it = groupmap.find(name);
+        
+        if (it != groupmap.end()) { error = 1; m->mothurOut("Your groupfile contains more than 1 sequence named " + name + ", sequence names must be unique. Please correct."); m->mothurOutEndLine();  }
+        else {
+            groupmap[name] = group;	//store data in map
+            seqsPerGroup[group]++;  //increment number of seqs in that group
+        }
+
+        
+        return error;
+    }
+    catch(exception& e) {
+        m->errorOut(e, "GroupMap", "addSeq");
+        exit(1);
+    }
+}
+/************************************************************/
 int GroupMap::readMap() {
     try {
         string seqName, seqGroup;
@@ -40,7 +66,8 @@ int GroupMap::readMap() {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
             
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -65,7 +92,8 @@ int GroupMap::readMap() {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -110,7 +138,8 @@ int GroupMap::readDesignMap() {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -135,7 +164,8 @@ int GroupMap::readDesignMap() {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -184,7 +214,8 @@ int GroupMap::readMap(string filename) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -209,7 +240,8 @@ int GroupMap::readMap(string filename) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -257,7 +289,8 @@ int GroupMap::readDesignMap(string filename) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -282,7 +315,8 @@ int GroupMap::readDesignMap(string filename) {
                 if (columnOne) {  seqName = pieces[i]; columnOne=false; }
                 else  { seqGroup = pieces[i]; pairDone = true; columnOne=true; }
                 
-                if (pairDone) { 
+                if (pairDone) {
+                    m->checkGroupName(seqGroup);
                     setNamesOfGroups(seqGroup);
                     
                     if (m->debug) { m->mothurOut("[DEBUG]: name = '" + seqName + "', group = '" + seqGroup + "'\n"); }
@@ -328,6 +362,7 @@ string GroupMap::getGroup(string sequenceName) {
 /************************************************************/
 
 void GroupMap::setGroup(string sequenceName, string groupN) {
+    m->checkGroupName(groupN);
 	setNamesOfGroups(groupN);
 	m->checkName(sequenceName);
 	it = groupmap.find(sequenceName);
