@@ -26,8 +26,8 @@ class SequenceCountParser {
 	
 public:
 	
-    SequenceCountParser(string, string);			//count, fasta - file mismatches will set m->control_pressed = true
-    SequenceCountParser(string, CountTable&);		//fasta, counttable - file mismatches will set m->control_pressed = true
+    SequenceCountParser(string, string, vector<string>);			//count, fasta - file mismatches will set m->control_pressed = true
+    SequenceCountParser(string, CountTable&, vector<string>);		//fasta, counttable - file mismatches will set m->control_pressed = true
     ~SequenceCountParser();
     
     //general operations
@@ -38,20 +38,22 @@ public:
     vector<Sequence> getSeqs(string); //returns unique sequences in a specific group
     map<string, int> getCountTable(string); //returns seqName -> numberOfRedundantSeqs for a specific group - the count file format, but each line is parsed by group.
     
-    int getSeqs(string, string, string, string, bool); //prints unique sequences in a specific group to a file - group, filename, uchimeFormat=false, tag (/ab= or ;size=), tag2(/ or ;)
+    int getSeqs(string, string, string, string, long long&, bool); //prints unique sequences in a specific group to a file - group, filename, uchimeFormat=false, tag (/ab= or ;size=), tag2(/ or ;)
     int getCountTable(string, string); //print seqName -> numberRedundantSeqs for a specific group - group, filename
     
-    map<string, string> getAllSeqsMap(){ return allSeqsMap; }  //returns map where the key=sequenceName and the value=representativeSequence - helps us remove duplicates after group by group processing
+    map<string, string> getAllSeqsMap(); //returns map where the key=sequenceName and the value=representativeSequence - helps us remove duplicates after group by group processing
 private:
 	
     CountTable countTable;
     MothurOut* m;
 	
     int numSeqs;
-    map<string, string> allSeqsMap;
+    vector<int> indexes;
+    //map<string, string> allSeqsMap;
     map<string, vector<Sequence> > seqs; //a vector for each group
     map<string, map<string, int> > countTablePerGroup; //countTable for each group
     vector<string> namesOfGroups;
+    int readFasta(string fastafile, CountTable&);
 };
 
 
