@@ -36,15 +36,16 @@ InteractEngine::InteractEngine(string path){
 	
 	//this will happen if you set the path variable to contain mothur's exe location
 	if (temppath == "") { path = mout->findProgramPath("mothur"); }
+    else { path = temppath; }
 	
-	mout->argv = path;
+	mout->mothurProgramPath = mout->getFullPathName(path);
+    mout->setBlastPath(mout->mothurProgramPath);
 
     //if you haven't set your own location
     #ifdef MOTHUR_FILES
     #else
         //set default location to search for files to mothur's executable location.  This will resolve issue of double-clicking on the executable which opens mothur and sets pwd to your home directory instead of the mothur directory and leads to "unable to find file" errors.
-        string tempDefault = path.substr(0, (path.find_last_of('m')));
-        if (tempDefault != "") { mout->setDefaultPath(tempDefault); }
+        if (mout->mothurProgramPath != "") { mout->setDefaultPath(mout->mothurProgramPath); }
     #endif
 }
 
@@ -173,15 +174,16 @@ BatchEngine::BatchEngine(string path, string batchFileName){
 	
 		//this will happen if you set the path variable to contain mothur's exe location
 		if (temppath == "") { path = mout->findProgramPath("mothur"); }
+        else { path = temppath; }
 		
-		mout->argv = path;
+		mout->mothurProgramPath = mout->getFullPathName(path);
+        mout->setBlastPath(mout->mothurProgramPath);
         
         //if you haven't set your own location
 #ifdef MOTHUR_FILES
 #else
         //set default location to search for files to mothur's executable location.  This will resolve issue of double-clicking on the executable which opens mothur and sets pwd to your home directory instead of the mothur directory and leads to "unable to find file" errors.
-        string tempDefault = path.substr(0, (path.find_last_of('m')));
-        if (tempDefault != "") { mout->setDefaultPath(tempDefault); }
+        if (mout->mothurProgramPath != "") { mout->setDefaultPath(mout->mothurProgramPath); }
 #endif
 
 				
@@ -257,7 +259,8 @@ bool BatchEngine::getInput(){
 							
 					//if we aborted command
 					if (quitCommandCalled == 2) {  mout->mothurOut("[ERROR]: did not complete " + commandName + ".\n");  }
-
+                    
+                    if (mout->control_pressed) { break;  }
 					mout->control_pressed = 0;
 					mout->executing = false;
 										
@@ -307,15 +310,17 @@ ScriptEngine::ScriptEngine(string path, string commandString){
 
 		//this will happen if you set the path variable to contain mothur's exe location
 		if (temppath == "") { path = mout->findProgramPath("mothur"); }
+        else { path = temppath; }
 		
-		mout->argv = path;
+		mout->mothurProgramPath = mout->getFullPathName(path);
+        mout->setBlastPath(mout->mothurProgramPath);
     
         //if you haven't set your own location
 #ifdef MOTHUR_FILES
 #else
         //set default location to search for files to mothur's executable location.  This will resolve issue of double-clicking on the executable which opens mothur and sets pwd to your home directory instead of the mothur directory and leads to "unable to find file" errors.
-        string tempDefault = path.substr(0, (path.find_last_of('m')));
-        if (tempDefault != "") { mout->setDefaultPath(tempDefault); }
+        //string tempDefault = path.substr(0, (path.find_last_of('m')));
+        if (path != "") { mout->setDefaultPath(path); }
 #endif
 
 				
@@ -391,7 +396,8 @@ bool ScriptEngine::getInput(){
 					
 					//if we aborted command
 					if (quitCommandCalled == 2) {  mout->mothurOut("[ERROR]: did not complete " + commandName + ".\n");  }
-							
+					
+                    if (mout->control_pressed) { break;  }
 					mout->control_pressed = 0;
 					mout->executing = false;
 									
