@@ -460,7 +460,7 @@ int LinearAlgebra::qtli(vector<double>& d, vector<double>& e, vector<vector<doub
 					if(fabs(e[myM])+dd == dd) break;
 				}
 				if(myM != l){
-					if(iter++ == 3000) cerr << "Too many iterations in tqli\n";
+					if(iter++ == 3000) cerr << "Too many iterations in qtli\n";
 					g = (d[l+1]-d[l]) / (2.0 * e[l]);
 					r = pythag(g, 1.0);
 					g = d[myM] - d[l] + e[l] / (g + SIGN(r,g));
@@ -1326,8 +1326,8 @@ double LinearAlgebra::calcKruskalWallis(vector<spearmanRank>& values, double& pV
 /*********************************************************************************************************************************/
 double LinearAlgebra::normalvariate(double mean, double standardDeviation) {
     try {
-        double u1 = ((double)(rand()) + 1.0 )/( (double)(RAND_MAX) + 1.0);
-        double u2 = ((double)(rand()) + 1.0 )/( (double)(RAND_MAX) + 1.0);
+        double u1 = m->getRandomDouble0to1();
+        double u2 = m->getRandomDouble0to1();
         //double r = sqrt( -2.0*log(u1) );
         //double theta = 2.0*PI*u2;
         //cout << cos(8.*atan(1.)*u2)*sqrt(-2.*log(u1)) << endl;
