@@ -29,6 +29,9 @@ struct logger {
     
 }; 
 /***********************************************/
+class OrderVector;
+class SharedOrderVector;
+class SharedRAbundVector;
 
 class MothurOut {
 	
@@ -46,6 +49,10 @@ class MothurOut {
 		void closeLog();
 		string getDefaultPath() { return defaultPath; }
 		void setDefaultPath(string);
+        string getTestFilePath() { return testFilePath; }
+        void setTestFilePath(string);
+        string getBlastPath() { return blastPath; }
+        void setBlastPath(string);
 		string getOutputDir() { return outputDir; }
 		void setOutputDir(string);
 		
@@ -69,7 +76,7 @@ class MothurOut {
 		vector<string> sharedBinLabelsInFile;
 		vector<string> currentSharedBinLabels;
         vector<string> listBinLabelsInFile;
-		string saveNextLabel, argv, sharedHeaderMode, groupMode, testDirectory;
+		string saveNextLabel, mothurProgramPath, sharedHeaderMode, groupMode, testDirectory;
 		bool printedSharedHeaders, printedListHeaders, commandInputsConvertError, changedSeqNames, modifyNames;
 		
 		//functions from mothur.h
@@ -114,7 +121,7 @@ class MothurOut {
 		int openInputFile(string, ifstream&, string); //no error given
         vector<bool> allGZFiles(vector<string>&);
         vector<bool> isGZ(string); //checks existence and format - will fail for either or both.
-    
+        bool fileExists(string name);
         bool checkLocations(string&, string);  //filename, inputDir. checks for file in ./, inputdir, default and mothur's exe location.  Returns false if cant be found. If found completes name with location
 		string getline(ifstream&);
 		string getline(istringstream&);
@@ -125,6 +132,7 @@ class MothurOut {
         void zapGremlins(istringstream&);
         vector<string> splitWhiteSpace(string& rest, char[], int);
         vector<string> splitWhiteSpace(string);
+        int splitWhiteSpace(string, vector<float>&, int);
         set<string> readAccnos(string);
         int readAccnos(string, vector<string>&);
         int readAccnos(string, vector<string>&, string);
@@ -163,9 +171,12 @@ class MothurOut {
 		bool isTrue(string);
 		bool isContainingOnlyDigits(string);
         bool containsAlphas(string);
+        bool isAllAlphas(string);
+        bool isAllAlphaNumerics(string);
 		bool isNumeric1(string);
         bool isNumeric1(char);
         bool isInteger(string);
+        bool allSpaces(string);
         bool isLabelEquivalent(string, string);
         string getSimpleLabel(string);
         string findEdianness();
@@ -193,9 +204,19 @@ class MothurOut {
         string makeList(vector<string>&);
         bool isSubset(vector<string>, vector<string>); //bigSet, subset
         int checkName(string&);
-    bool checkGroupName(string name);
+        bool checkGroupName(string name);
         map<string, vector<string> > parseClasses(string);
         string addUnclassifieds(string tax, int maxlevel, bool probs);
+        int mothurRandomShuffle(vector<int>&);
+        int mothurRandomShuffle(vector< vector<double> >&);
+        int mothurRandomShuffle(vector<string>&);
+        int mothurRandomShuffle(vector<item>&);
+        int mothurRandomShuffle(vector<PCell*>&);
+        int mothurRandomShuffle(vector<PDistCellMin>&);
+        int mothurRandomShuffle(OrderVector&);
+        int mothurRandomShuffle(SharedOrderVector&);
+        int mothurRandomShuffle(vector<SharedRAbundVector*>&);
+        void setRandomSeed(unsigned s) { mersenne_twister_engine.seed(s); }
     
 		
 		//math operation
@@ -212,7 +233,10 @@ class MothurOut {
         int median(vector<int>);
         int average(vector<int>);
         int sum(vector<int>);
+        double sum(vector<double>);
 		int getRandomIndex(int); //highest
+        int getRandomNumber();
+        double getRandomDouble0to1();
         double getStandardDeviation(vector<int>&);
         vector<double> getStandardDeviation(vector< vector<double> >&);
         vector<double> getStandardDeviation(vector< vector<double> >&, vector<double>&);
@@ -226,7 +250,7 @@ class MothurOut {
 		int control_pressed;
 		bool executing, runParse, jumble, gui, mothurCalling, debug, quietMode;
 		
-		//current files - if you add a new type you must edit optionParser->getParameters, get.current and set.current commands and mothurOut->printCurrentFiles/clearCurrentFiles/getCurrentTypes. add a get and set function.
+		//current files - if you add a new type you must edit optionParser->getParameters, get.current and set.current commands and mothurOut->printCurrentFiles/clearCurrentFiles/getCurrentTypes/hasCurrentFiles. add a get and set function.
 		string getPhylipFile()		{ return phylipfile;		}
 		string getColumnFile()		{ return columnfile;		}
 		string getListFile()		{ return listfile;			}
@@ -252,6 +276,8 @@ class MothurOut {
         string getSummaryFile()     { return summaryfile;       }
         string getFileFile()        { return filefile;          }
 		string getProcessors()		{ return processors;		}
+        string getConsTaxonomyFile(){ return constaxonomyfile;  }
+        string getContigsReportFile(){ return contigsreportfile;  }
         int getNumErrors()          { return numErrors;         }
 		
 		void setListFile(string f)			{ listfile = getFullPathName(f);			}
@@ -277,6 +303,8 @@ class MothurOut {
         void setBiomFile(string f)			{ biomfile = getFullPathName(f);			}
         void setSummaryFile(string f)		{ summaryfile = getFullPathName(f);			}
         void setFileFile(string f)          { filefile = getFullPathName(f);			}
+        void setConsTaxonomyFile(string f)  { constaxonomyfile = getFullPathName(f);	}
+        void setContigsReportFile(string f) { contigsreportfile = getFullPathName(f);	}
         void setCountTableFile(string f)	{ counttablefile = getFullPathName(f);	groupMode = "count";	}
         void setProcessors(string p)		{ processors = p; mothurOut("\nUsing " + toString(p) + " processors.\n");	}
 		
@@ -290,7 +318,7 @@ class MothurOut {
 		MothurOut( const MothurOut& ); // Disable copy constructor
 		void operator=( const MothurOut& ); // Disable assignment operator
 		MothurOut() { 
-			control_pressed = false; defaultPath="";
+			control_pressed = false; defaultPath=""; blastPath=""; testFilePath = "";
             filefile = "";
 			phylipfile = "";
 			columnfile = "";
@@ -311,11 +339,13 @@ class MothurOut {
 			oligosfile = "";
 			accnosfile = "";
 			taxonomyfile = "";
+            constaxonomyfile = "";
 			processors = "1";
 			flowfile = "";
             biomfile = "";
             counttablefile = "";
             summaryfile = "";
+            contigsreportfile = "";
 			gui = false;
 			printedSharedHeaders = false;
             printedListHeaders = false;
@@ -329,15 +359,18 @@ class MothurOut {
             modifyNames = true;
             numErrors = 0;
             numWarnings = 0;
+            unsigned seed = std::chrono::system_clock::now().time_since_epoch().count();
+            mersenne_twister_engine.seed(seed);
 		}
 		~MothurOut();
 
 		string logFileName;
-		string defaultPath, outputDir;
+		string defaultPath, outputDir, blastPath;
 		string releaseDate, version;
 	
-		string accnosfile, phylipfile, columnfile, listfile, rabundfile, sabundfile, namefile, groupfile, designfile, taxonomyfile, biomfile, filefile;
-		string orderfile, treefile, sharedfile, ordergroupfile, relabundfile, fastafile, qualfile, sfffile, oligosfile, processors, flowfile, counttablefile, summaryfile;
+		string accnosfile, phylipfile, columnfile, listfile, rabundfile, sabundfile, namefile, groupfile, designfile, taxonomyfile, biomfile, filefile, testFilePath;
+		string orderfile, treefile, sharedfile, ordergroupfile, relabundfile, fastafile, qualfile, sfffile, oligosfile, processors, flowfile, counttablefile, summaryfile, constaxonomyfile, contigsreportfile;
+        mt19937_64 mersenne_twister_engine;
 
 		vector<string> Groups;
 		vector<string> namesOfGroups;
