@@ -10,8 +10,8 @@
 class Rarefact {
 	
 public:
-	Rarefact(OrderVector* o, vector<Display*> disp, int p, set<int> en) :
-			numSeqs(o->getNumSeqs()), order(o), displays(disp), label(o->getLabel()), processors(p), ends(en)  { m = MothurOut::getInstance(); }
+	Rarefact(OrderVector& o, vector<Display*> disp, int p, set<int> en) :
+			numSeqs(o.getNumSeqs()), order(o), displays(disp), label(o.getLabel()), processors(p), ends(en)  { m = MothurOut::getInstance(); }
 	Rarefact(vector<SharedRAbundVector*> shared, vector<Display*> disp) :
 					 lookup(shared), displays(disp) {  m = MothurOut::getInstance(); }
 
@@ -21,7 +21,7 @@ public:
 	
 private:
 	
-	OrderVector* order;
+	OrderVector order;
 	vector<Display*> displays;
 	int numSeqs, numGroupComb, processors;
 	string label;
